
/*
 *   This file is part of PhpCompta.
 *
 *   PhpCompta is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   PhpCompta is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with PhpCompta; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
CREATE SEQUENCE seq_jnt_use_dos
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;

create table jnt_use_dos
(
	jnt_id integer DEFAULT nextval('seq_jnt_use_dos'::text) NOT NULL,
	use_id	int4 not null references ac_users(use_id),
	dos_id int4 not null references ac_dossier(dos_id),
	primary key (use_id,dos_id)
);
create index fk_jnt_use_dos on jnt_use_dos(use_id);
create index fk_jnt_dos_id on jnt_use_dos(dos_id);
